Module: LesliView

Defined in:
lib/lesli_view/engine.rb,
lib/lesli_view.rb,
lib/lesli_view/version.rb,
lib/lesli_view/charts/bar.rb,
lib/lesli_view/items/task.rb,
lib/lesli_view/charts/line.rb,
lib/lesli_view/items/tasks.rb,
lib/lesli_view/forms/fields.rb,
lib/lesli_view/forms/inputs.rb,
lib/lesli_view/widgets/date.rb,
lib/lesli_view/forms/builder.rb,
lib/lesli_view/items/actions.rb,
lib/lesli_view/widgets/chart.rb,
lib/lesli_view/widgets/count.rb,
lib/lesli_view/charts/general.rb,
lib/lesli_view/elements/empty.rb,
lib/lesli_view/elements/table.rb,
lib/lesli_view/forms/fieldset.rb,
lib/lesli_view/components/tabs.rb,
lib/lesli_view/elements/avatar.rb,
lib/lesli_view/elements/button.rb,
lib/lesli_view/widgets/weather.rb,
lib/lesli_view/components/panel.rb,
lib/lesli_view/items/activities.rb,
lib/lesli_view/items/discussion.rb,
lib/lesli_view/layout/container.rb,
lib/lesli_view/widgets/calendar.rb,
lib/lesli_view/components/header.rb,
lib/lesli_view/items/attachments.rb,
lib/lesli_view/items/discussions.rb,
lib/lesli_view/components/toolbar.rb,
lib/lesli_view/components/timeline.rb,
lib/lesli_view/partials/engine_spec.rb,
lib/lesli_view/forms/builder_horizontal.rb

Overview

Lesli

Copyright © 2025, Lesli Technologies, S. A.

This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program. If not, see www.gnu.org/licenses/.

Lesli · Ruby on Rails SaaS Development Framework.

Made with ♥ by LesliTech Building a better future, one line of code at a time.

// · ~·~ ~·~ ~·~ ~·~ ~·~ ~·~ ~·~ ~·~ ~·~ // ·

Defined Under Namespace

Modules: Charts, Components, Elements, Forms, Items, Layout, Partials, Widgets Classes: Engine, Error

Constant Summary collapse

VERSION =
"1.1.1"
BUILD =
"1777174912"